@@ -1,8 +1,6 @@
 #
 # Copyright 2013 Red Hat, Inc
 #
-# Author:  Eoghan Glynn <eglynn@redhat.com>
-#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -30,6 +28,7 @@ AN_ALARM = {u'alarm_actions': [u'http://site:8000/alarm'],
             u'ok_actions': [u'http://site:8000/ok'],
             u'description': u'An alarm',
             u'type': u'threshold',
+            u'severity': 'low',
             u'threshold_rule': {
                 u'meter_name': u'storage.objects',
                 u'query': [{u'field': u'key_name',
@@ -109,6 +108,7 @@ AN_LEGACY_ALARM = {u'alarm_actions': [u'http://site:8000/alarm'],
                    u'period': 240.0,
                    u'alarm_id': u'alarm-id',
                    u'state': u'ok',
+                   u'severity': u'low',
                    u'insufficient_data_actions': [u'http://site:8000/nodata'],
                    u'statistic': u'avg',
                    u'threshold': 200.0,
