@@ -32,15 +32,17 @@ from ceilometerclient.v2 import traits
 class Client(object):
     """Client for the Ceilometer v2 API.
 
-    :param string endpoint: A user-supplied endpoint URL for the ceilometer
+    :param endpoint: A user-supplied endpoint URL for the ceilometer
                             service.
-    :param function token: Provides token for authentication.
-    :param integer timeout: Allows customization of the timeout for client
-                            http requests. (optional)
+    :type endpoint: string
+    :param token: Provides token for authentication.
+    :type token: function
+    :param timeout: Allows customization of the timeout for client
+                    http requests. (optional)
+    :type timeout: integer
     """
 
     def __init__(self, *args, **kwargs):
-
         """Initialize a new client for the Ceilometer v2 API."""
         self.auth_plugin = kwargs.get('auth_plugin') \
             or ceiloclient.get_auth_plugin(*args, **kwargs)
@@ -50,7 +52,7 @@ class Client(object):
             endpoint_type=kwargs.get('endpoint_type'),
             original_ip=kwargs.get('original_ip'),
             verify=kwargs.get('verify'),
-            cert=kwargs.get('cacert'),
+            cert=kwargs.get('cert'),
             timeout=kwargs.get('timeout'),
             timings=kwargs.get('timings'),
             keyring_saver=kwargs.get('keyring_saver'),
@@ -61,7 +63,8 @@ class Client(object):
 
         self.http_client = client.BaseClient(self.client)
         self.meters = meters.MeterManager(self.http_client)
-        self.samples = samples.SampleManager(self.http_client)
+        self.samples = samples.OldSampleManager(self.http_client)
+        self.new_samples = samples.SampleManager(self.http_client)
         self.statistics = statistics.StatisticsManager(self.http_client)
         self.resources = resources.ResourceManager(self.http_client)
         self.alarms = alarms.AlarmManager(self.http_client)
